
------------------------------------------------

local function Atr_AppendHint (results, price, text, volume)

	if (price and price > 0) then
		local e = {};
		e.price		= price;
		e.text		= text;
		e.volume	= volume;
		
		table.insert (results, e);
	end

end

------------------------------------------------

local function Atr_BuildHints (itemLink, itemName)

	local results = {};

	if (itemLink == nil and itemName == nil) then
		return results;
	end

	-- Auctionator Full Scan
	
	if (itemName ~= nil and AUCTIONATOR_PRICE_DATABASE[itemName] ~= nil) then
		Atr_AppendHint (results, AUCTIONATOR_PRICE_DATABASE[itemName], "Auctionator scan data");
	end

	-- most recent historical price
	
	local price = Atr_GetMostRecentSale(itemName);
	if (price ~= nil) then
		Atr_AppendHint (results, price, "your most recent posting");
	end

	-- Wowecon

	if (Wowecon and Wowecon.API) then
	
		local priceG, volG, priceS, volS;
		
		if (itemLink) then
			priceG, volG = Wowecon.API.GetAuctionPrice_ByLink (itemLink, Wowecon.API.GLOBAL_PRICE)
			priceS, volS = Wowecon.API.GetAuctionPrice_ByLink (itemLink, Wowecon.API.SERVER_PRICE)
		else
			priceG, volG = Wowecon.API.GetAuctionPrice_ByName (itemName, Wowecon.API.GLOBAL_PRICE)
			priceS, volS = Wowecon.API.GetAuctionPrice_ByName (itemName, Wowecon.API.SERVER_PRICE)
		end
		
		Atr_AppendHint (results, priceG, "Wowecon global price", volG);
		Atr_AppendHint (results, priceS, "Wowecon server price", volS);
		
	end
	
	if (itemLink) then
	
		-- GoingPrice Wowhead
		
		local id = ZC_ItemIDfromLink (itemLink);
		
		id = tonumber(id);

		if (GoingPrice_Wowhead_Data and GoingPrice_Wowhead_Data[id] and GoingPrice_Wowhead_SV._index) then
			local index = GoingPrice_Wowhead_SV._index["Buyout price"];

			if (index ~= nil) then
				local price = GoingPrice_Wowhead_Data[id][index];
			
				Atr_AppendHint (results, price, "GoingPrice - Wowhead");
			end
		end

		-- GoingPrice Allakhazam
		
		if (GoingPrice_Allakhazam_Data and GoingPrice_Allakhazam_Data[id] and GoingPrice_Allakhazam_SV._index) then
			local index = GoingPrice_Allakhazam_SV._index["Median"];

			if (index ~= nil) then
				local price = GoingPrice_Allakhazam_Data[id][index];
			
				Atr_AppendHint (results, price, "GoingPrice - Allakhazam");
			end
		end
	end
	
	return results;

end

-----------------------------------------

function Atr_ShowHints ()

	Atr_Col1_Heading:Hide();
	Atr_Col3_Heading:Hide();
	Atr_Col4_Heading:Hide();

	Atr_Col3_Heading:SetText ("Source");

	local currentPane = Atr_GetCurrentPane();

	currentPane.hints = Atr_BuildHints (currentPane.itemLink, currentPane.itemName);
	
	local numrows = #currentPane.hints;

	if (numrows > 0) then
		Atr_Col1_Heading:Show();
		Atr_Col3_Heading:Show();
	end

	local line;							-- 1 through 12 of our window to scroll
	local dataOffset;					-- an index into our data calculated from the scroll offset

	FauxScrollFrame_Update (AuctionatorScrollFrame, numrows, 12, 16);

	for line = 1,12 do

		dataOffset = line + FauxScrollFrame_GetOffset (AuctionatorScrollFrame);

		local lineEntry = getglobal ("AuctionatorEntry"..line);

		lineEntry:SetID(dataOffset);

		if (dataOffset <= numrows and currentPane.hints[dataOffset]) then

			local data = currentPane.hints[dataOffset];

			local lineEntry_item_tag = "AuctionatorEntry"..line.."_PerItem_Price";

			local lineEntry_item		= getglobal(lineEntry_item_tag);
			local lineEntry_itemtext	= getglobal("AuctionatorEntry"..line.."_PerItem_Text");
			local lineEntry_text		= getglobal("AuctionatorEntry"..line.."_EntryText");
			local lineEntry_stack		= getglobal("AuctionatorEntry"..line.."_StackPrice");

			lineEntry_item:Show();
			lineEntry_itemtext:Hide();
			lineEntry_stack:SetText	("");

			Atr_SetMFcolor (lineEntry_item_tag, true);

			MoneyFrame_Update (lineEntry_item_tag, ZC_round(data.price) );

			local text = data.text;
			if (data.volume) then
				text = text.." (trade volume: "..data.volume..")";
			end
			
			lineEntry_text:SetText (text);
			lineEntry_text:SetTextColor (0.8, 0.8, 1.0);

			lineEntry:Show();
		else
			lineEntry:Hide();
		end
	end

	if (#currentPane.hints and not currentPane.hintsIndex) then
		currentPane.hintsIndex = 1;
	end
	
	Atr_HighlightEntry (currentPane.hintsIndex);
end


-----------------------------------------

function Atr_SetMFcolor (frameName, blue)

	local goldButton = getglobal(frameName.."GoldButton");
	local silverButton = getglobal(frameName.."SilverButton");
	local copperButton = getglobal(frameName.."CopperButton");

	if (blue) then
		goldButton:SetNormalFontObject(NumberFontNormalRightATRblue);
		silverButton:SetNormalFontObject(NumberFontNormalRightATRblue);
		copperButton:SetNormalFontObject(NumberFontNormalRightATRblue);
	else
		goldButton:SetNormalFontObject(NumberFontNormalRight);
		silverButton:SetNormalFontObject(NumberFontNormalRight);
		copperButton:SetNormalFontObject(NumberFontNormalRight);
	end
	
end


-----------------------------------------

local function Atr_CalcTextWid (price)

	local wid = 15;
	
	if (price > 9)			then wid = wid + 12;	end;
	if (price > 99)			then wid = wid + 42;	end;
	if (price > 999)		then wid = wid + 12;	end;
	if (price > 9999)		then wid = wid + 42;	end;
	if (price > 99999)		then wid = wid + 12;	end;
	if (price > 999999)		then wid = wid + 12;	end;
	if (price > 9999999)	then wid = wid + 12;	end;
	if (price > 99999999)	then wid = wid + 12;	end;
	
	return wid;
end

-----------------------------------------

local function ShowTipWithPricing (tip, link)

	if (AUCTIONATOR_SHOW_TIPS ~= 1 or link == nil) then
		return;
	end
	
	local itemName	= GetItemInfo (link);
	local itemID	= ZC_ItemIDfromLink (link);
	
	itemID = tonumber(itemID);
	
	local vendorPrice;
	local auctionPrice;
	
	if (gAtr_VendorPrices[itemID]) then
		vendorPrice = gAtr_VendorPrices[itemID];
	end

	if (AUCTIONATOR_PRICE_DATABASE[itemName]) then
		auctionPrice = AUCTIONATOR_PRICE_DATABASE[itemName];
	end
	
	if (auctionPrice == nil) then
		auctionPrice = Atr_GetMostRecentSale (itemName);
	end
	
	if (gAtr_VendorPrices[itemID] > 0) then
	
		local padding = "";

		if (vendorPrice and auctionPrice) then
			local vpwidth = Atr_CalcTextWid (vendorPrice);
			local apwidth = Atr_CalcTextWid (auctionPrice);

			local padlen = math.floor ((apwidth - vpwidth)/6);
			local k;
			
			for k = 1,padlen do
				padding = padding.." ";
			end
		end
		
		tip:AddLine ("Vendor:    |cFFFFFFFF"..padding..ZC_priceToMoneyString (vendorPrice))
	end
	
	if (auctionPrice ~= nil) then
		tip:AddLine ("Auction:   |cFFFFFFFF"..ZC_priceToMoneyString (auctionPrice));
	else
		tip:AddLine ("Auction:   |cFFFFFFFFunknown");
	end

	tip:Show()

end

-----------------------------------------

hooksecurefunc (GameTooltip, "SetBagItem",
	function(tip, bag, slot)
		ShowTipWithPricing (tip, GetContainerItemLink(bag, slot));
	end
);

hooksecurefunc (GameTooltip, "SetAuctionItem",
	function (tip, type, index)
		ShowTipWithPricing (tip, GetAuctionItemLink(type, index));
	end
);

hooksecurefunc (GameTooltip, "SetAuctionSellItem",
	function (tip)
		local name, link = GetItemInfo(GetAuctionSellItemInfo());
		ShowTipWithPricing (tip, link);
	end
);


hooksecurefunc (GameTooltip, "SetLootItem",
	function (tip, slot)
		if LootSlotIsItem(slot) then
			ShowTipWithPricing (tip, GetLootSlotLink(slot));
		end
	end
);

hooksecurefunc (GameTooltip, "SetLootRollItem",
	function (tip, slot)
		ShowTipWithPricing (tip, GetLootRollItemLink(slot));
	end
);


hooksecurefunc (GameTooltip, "SetInventoryItem",
	function (tip, unit, slot)
		ShowTipWithPricing (tip, GetInventoryItemLink(unit, slot));
	end
);

hooksecurefunc (GameTooltip, "SetGuildBankItem",
	function (tip, tab, slot)
		ShowTipWithPricing (tip, GetGuildBankItemLink(tab, slot));
	end
);

hooksecurefunc (GameTooltip, "SetTradeSkillItem",
	function (tip, skill, id)
		local link = GetTradeSkillItemLink(skill);
		if id then
			link = GetTradeSkillReagentItemLink(skill, id);
		end
		ShowTipWithPricing (tip, link);
	end
);

hooksecurefunc (GameTooltip, "SetTradePlayerItem",
	function (tip, id)
		ShowTipWithPricing (tip, GetTradePlayerItemLink(id));
	end
);

hooksecurefunc (GameTooltip, "SetTradeTargetItem",
	function (tip, id)
		ShowTipWithPricing (tip, GetTradeTargetItemLink(id));
	end
);

hooksecurefunc (GameTooltip, "SetQuestItem",
	function (tip, type, index)
		ShowTipWithPricing (tip, GetQuestItemLink(type, index));
	end
);

hooksecurefunc (GameTooltip, "SetQuestLogItem",
	function (tip, type, index)
		ShowTipWithPricing (tip, GetQuestLogItemLink(type, index));
	end
);

hooksecurefunc (GameTooltip, "SetInboxItem",
	function (tip, index, attachIndex)
		ShowTipWithPricing (tip, GetInboxItemLink(index, attachIndex));
	end
);

hooksecurefunc (GameTooltip, "SetSendMailItem",
	function (tip, id)
		local name, link = GetItemInfo(GetSendMailItem(id));
		ShowTipWithPricing (tip, link);
	end
);

hooksecurefunc (GameTooltip, "SetHyperlink",
	function (tip, itemstring, count)
		local name, link = GetItemInfo (itemstring);
		ShowTipWithPricing (tip, link);
	end
);

hooksecurefunc (ItemRefTooltip, "SetHyperlink",
	function (tip, itemstring, count)
		local name, link = GetItemInfo (itemstring);
		ShowTipWithPricing (tip, link);
	end
);










